==> privacybadger_2019.2.19.orig.tar.gz: privacybadger-release-2019.2.19/CONTRIBUTING.md <==
# Contributing to Privacy Badger

Welcome dear contributor! There are many ways to help Privacy Badger. From
quick and whimsical to involved and academic. From JavaScript to Japanese, from
algorithmic to stylistic. There is surely a way you can help.

Here is a quick orientation to guide your adventure:

* Did we break a site? We want to fix it,
  so we wrote a [guide to fixing broken sites](/doc/fixing-broken-sites.md).
* Want to help translate Privacy Badger? Working on a pull request that
  involves updating translations?
  Please see our [guide to translating Privacy Badger](/doc/Translation.md).
* To review issues we would like help with, visit our
  ["good first issue"](https://github.com/EFForg/privacybadger/labels/good%20first%20issue)
  and
  ["help wanted"](https://github.com/EFForg/privacybadger/labels/help%20wanted)
  labels.
* When making changes to Privacy Badger's code, please consult our [developer](/doc/develop.md) and [automated testing](/doc/tests.md) guides.
* Security vulnerabilities can be reported privately to
  [vulnerabilities@eff.org](mailto:vulnerabilities@eff.org). Please see our
  [Security Vulnerability Disclosure Program](https://www.eff.org/security)
  for the GPG key and more information.
<!---
* This short overview of Privacy Badger's architecture can help put things in perspective.
* Developer setup and debugging.
-->

If you find something confusing or frustrating, please let us know!
We believe in making Privacy Badger better by making it easier for you to contribute.

Thank you!

==> privacybadger_2020.2.19.orig.tar.gz: privacybadger-release-2020.2.19/CONTRIBUTING.md <==
# Contributing to Privacy Badger

Welcome dear contributor! There are many ways to help Privacy Badger. From
quick and whimsical to involved and academic. From JavaScript to Japanese, from
algorithmic to stylistic. There is surely a way you can help.

Here is a quick orientation to guide your adventure:

* Did we break a site? We want to fix it,
  so we wrote a [guide to fixing broken sites](/doc/fixing-broken-sites.md).
* Want to help translate Privacy Badger? Working on a pull request that
  involves updating translations?
  Please see our [guide to translating Privacy Badger](/doc/Translation.md).
* To review issues we would like help with, visit our
  ["good first issue"](https://github.com/EFForg/privacybadger/labels/good%20first%20issue)
  and
  ["help wanted"](https://github.com/EFForg/privacybadger/labels/help%20wanted)
  labels.
* When making changes to Privacy Badger's code, please consult our [developer](/doc/develop.md) and [automated testing](/doc/tests.md) guides.
* When interacting with us, please remember to follow [EFF's Public Projects Code of Conduct](https://www.eff.org/pages/eppcode).
* Security vulnerabilities can be reported privately to
  [vulnerabilities@eff.org](mailto:vulnerabilities@eff.org). Please see our
  [Security Vulnerability Disclosure Program](https://www.eff.org/security)
  for the GPG key and more information.
<!---
* This short overview of Privacy Badger's architecture can help put things in perspective.
* Developer setup and debugging.
-->

If you find something confusing or frustrating, please let us know!
We believe in making Privacy Badger better by making it easier for you to contribute.

Thank you!
